# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Ciphers"]


class Ciphers(BaseModel):
    """An allowlist of ciphers for TLS termination.

    These ciphers must be in the BoringSSL format.
    """

    id: Literal["ciphers"]
    """ID of the zone setting."""

    value: List[str]
    """Current value of the zone setting."""

    editable: Optional[Literal[True, False]] = None
    """
    Whether or not this setting can be modified for this zone (based on your
    Cloudflare plan level).
    """

    modified_on: Optional[datetime] = None
    """last time this setting was modified."""
